import { Table } from 'antd';
import { Layout } from 'antd';
import useTaskStore from '../services/taskService';
import { Task } from '../interfaces/task';
import { TimePipe } from '../utils/pipe';
import { Button } from 'antd';
import HeaderNav from '../components/HeaderNav';
import SideNav from '../components/SideNav';

const { Content } = Layout;

const columns = [
    {
        title: '标题',
        dataIndex: 'title',
        key: 'title',
    },
    {
        title: '描述',
        dataIndex: 'description',
        key: 'description',
    },
    {
        title: '创建日期',
        dataIndex: 'created_at',
        key: 'created_at',
        render: (v: number) => {
            return <TimePipe timestamp={v} />;
        },
    },
    {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
    },
];

const TaskPage = () => {
    const { tasks } = useTaskStore();

    function onClickNewTask(e: React.MouseEvent<HTMLElement, MouseEvent>) {
        console.log('新建任务', e)
    }

    return (
        <Layout>
            <HeaderNav />
            <Layout>
                <SideNav />
                <Content
                    style={{
                        margin: '64px 0 0 200px',
                        padding: 24,
                        minHeight: 280,
                    }}
                >
                    {/* 新增的新建任务按钮 */}
                    <Button onClick={(e) => onClickNewTask(e)}>新建任务</Button>
                    <Table<Task>
                        columns={columns}
                        dataSource={tasks.map((v) => ({ ...v, key: v.id }))}
                        expandable={{
                            expandedRowRender: (v) => <p style={{ margin: 0 }}>{v.description}</p>,
                        }}
                    />
                </Content>
            </Layout>
        </Layout>
    );
};

export default TaskPage;